==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/trace/sample/loganalyzer/AnalyzeLogAction.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.hyades.trace.sample.loganalyzer;

import java.lang.reflect.InvocationTargetException;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.analysis.engine.AnalysisEngineConstants;
import org.eclipse.hyades.analysis.engine.AnalysisEnginePlugin;
import org.eclipse.hyades.log.ui.internal.views.ExtensionPointHandler;
import org.eclipse.hyades.log.ui.internal.views.ExtensionPointHandler.ConfigurationElement;
import org.eclipse.hyades.log.ui.internal.views.LogContentProvider;
import org.eclipse.hyades.log.ui.internal.views.LogPage;
import org.eclipse.hyades.log.ui.internal.views.LogPaneTreeViewer;
import org.eclipse.hyades.log.ui.internal.views.LogViewer;
import org.eclipse.hyades.sdb.internal.SDbPlugin;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.hyades.log.ui.internal.views.*;

/**
 * @author sleeloy
 *
 * This action class will analyze an apache error log using 
 * a specific symptom database.  The corresponding viewers are 
 * also refeshed to reflect the analyzed error log file.
 */
public class AnalyzeLogAction implements IRunnableWithProgress {

	private String symptomDBPath;
	private String projectName;
	private String sdbFileName;
	
	private ExtensionPointHandler eph = ExtensionPointHandler.getExtensionPointHandler();
	protected EObject mofObject;
	private LogPaneTreeViewer logPaneTreeViewer;	
	/**
	 * This method is were all the work is done.  The error log file is analyzed
	 * using a specified symptom database.  The Log Tree Viewer is also refreshed
	 * to reflect the analyzed error log file.
	 * 
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 * @param monitor - shows the progress of this action.
	 */
	public void run(IProgressMonitor monitor)
		throws InvocationTargetException, InterruptedException {
			//Need to set the symptom database path
			IPreferenceStore store = AnalysisEnginePlugin.getPlugin().getPreferenceStore();
			
			String value = getNewSDBPathPreference(store.getString(AnalysisEngineConstants.SYMPTOM_DB_PATH), symptomDBPath);
			store.setValue(AnalysisEngineConstants.SYMPTOM_DB_PATH, value);
			store.setValue(AnalysisEngineConstants.PROJECT_NAME, projectName);
			store.setValue(AnalysisEngineConstants.SDB_FILE_NAME, sdbFileName);

			/*
			 * These preferences will be stored in the sdb plugin
			 * in future releases. Store it there for future
			 * workspace compatibility.
			 */
			IPreferenceStore futureStore = SDbPlugin.getDefault().getPreferenceStore();

			futureStore.setValue(AnalysisEngineConstants.SYMPTOM_DB_PATH, value);
			futureStore.setValue(AnalysisEngineConstants.PROJECT_NAME, projectName);
			futureStore.setValue(AnalysisEngineConstants.SDB_FILE_NAME, sdbFileName);
			
			//Load symptom database
			IStructuredSelection  selection = getSelection();
			List aLogAnalyzerList = eph.getLogAnalyzers();
			LogAnalyzerImpl aLogAnalyzerImpl = null;
			
			if(aLogAnalyzerList != null && aLogAnalyzerList.size() >0)
			{
				for (Iterator iter = aLogAnalyzerList.iterator();
				iter.hasNext();
				) {
					ConfigurationElement config = (ConfigurationElement) iter.next();
					if(config.getAnalyzer() instanceof LogAnalyzerImpl){
						aLogAnalyzerImpl = (LogAnalyzerImpl)config.getAnalyzer();
						break;	
					}
				}
								
			}
			if(aLogAnalyzerImpl == null)
			    return;
			
			if (sdbFileName.length() > 0) aLogAnalyzerImpl.importDB(monitor); 
			aLogAnalyzerImpl.loadDatabase();
			if(aLogAnalyzerImpl.errorMsg()==null){	
				aLogAnalyzerImpl.analyze(selection);
			}
			logPaneTreeViewer.refresh();

			//Need to send an event so that the Analysis Result area will be updated.
			Event event = new Event();
			event.item = ((Tree) logPaneTreeViewer.getControl()).getItems()[0];
			logPaneTreeViewer.getControl().notifyListeners(SWT.Selection, event);			

	}
	/**
	 * 
	 * @return
	 */
	private String getNewSDBPathPreference(String previousValue, String symptomDBPath)
	{
		//	case 1
		// nothing is stores in the preference
		// previous.length() == 0 if nothing is stored in the preference
		if (previousValue.length() == 0) 
		{
			return symptomDBPath + ",1"; 
		}
		 else
		 {
			 int index = previousValue.indexOf(symptomDBPath);
		
		
			 if (index < 0)
			 {
				 // case 2
				 // symptomdbpath does not exist in preference (ie.db has not been loaded)
				   return symptomDBPath + ",1" + ";" + previousValue;
			   }	
			   else
			   {
	
				   if ((previousValue.substring(symptomDBPath.length() + index + 1,symptomDBPath.length() + index + 2 )).equals("0"))
				   {
					   //case 3
					   //loaded but is followed by ,0 - meaning not used for log analysis
					   //change 0 to 1
					   String temp1 = previousValue.substring(0, index + symptomDBPath.length() + 1);
					   String temp2 = previousValue.substring(index + symptomDBPath.length() + 2, previousValue.length());
					   return temp1 + "1" + temp2;
				   }
	
				   else if ((previousValue.substring(symptomDBPath.length() + index + 1, symptomDBPath.length() + index + 2)).equals("1"))
				   {
					   // case 4
					   // loaded and is follow by a ,1
					   // do nothing
					   return previousValue;
				   }
		
				 }
		 }
		 return "";
	}
	
	/**
	 * This class retrieves the entire content selection from the Log Viewer.  All the contents
	 * in the log viewer will be analyzed.
	 * 
	 * @return IStructureSelection that represents the records shown in the Log Viewer.
	 */
	public IStructuredSelection getSelection(){
		//return the entire content selection
		try {
					IWorkbenchPage persp = UIPlugin.getActivePage();
					LogViewer logviewer = (LogViewer)persp.showView("org.eclipse.hyades.log.ui.internal.views.LogViewer");
					LogPage logPage = (LogPage)logviewer.getPage(mofObject);
					if(logPage==null){
						logviewer.addViewPage(mofObject);
						logPage = (LogPage)logviewer.getPage(mofObject);
					}
					
					logPaneTreeViewer = logPage.getView().getViewer();
					LogContentProvider logContentProvider = (LogContentProvider)logPaneTreeViewer.getContentProvider();
					return new StructuredSelection(logContentProvider.getChildren(mofObject));
		} catch (PartInitException e) {
			e.printStackTrace();
		}
		return null;
	}


	/**
	 * Returns the symptom database location that is used to analyze the error log file.
	 * @return String that represents the symptom database location that is used to analyze the error log file.
	 */
	public String getSymptomDBPath() {
		return symptomDBPath;
	}

	/**
	 * Sets the symptom database location that is used to analyze the error log file.
	 * @param string - that represents the symptom database location that is used to analyze the error log file.
	 */
	public void setSymptomDBPath(String string) {
		symptomDBPath = string;
	}
	
	/**
	 * Sets the project Name of where to import the db into
	 * @param pName
	 */
	public void setProjectName(String pName)
	{
		projectName = pName;
	}
		
	/**
	 * specifies what the sdb file should be called in the workspace
	 * @param string
	 */
	public void setSDBFileName(String string)
	{
		sdbFileName = string;
	}
		
	

	/**
	 * Returns the Mof object that represents the error log file.  This object will be analyzed using the 
	 * specified symptom database.
	 * @return EObject represents the error log file that will be analyzed.
	 */
	public EObject getMofObject() {
		return mofObject;
	}

	/**
	 * Sets the Mof object that represents the error log file.  This object will be analyzed using the 
	 * specified symptom database.
	 * @param object - represents the error log file that will be analyzed.
	 */
	public void setMofObject(EObject object) {
		mofObject = object;
	}

}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/trace/sample/loganalyzer/AnalyzeLogAction.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.hyades.trace.sample.loganalyzer;

import java.lang.reflect.InvocationTargetException;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.log.ui.internal.views.ExtensionPointHandler;
import org.eclipse.hyades.log.ui.internal.views.ExtensionPointHandler.ConfigurationElement;
import org.eclipse.hyades.log.ui.internal.views.LogContentProvider;
import org.eclipse.hyades.log.ui.internal.views.LogPage;
import org.eclipse.hyades.log.ui.internal.views.LogPaneTreeViewer;
import org.eclipse.hyades.log.ui.internal.views.LogViewer;
import org.eclipse.hyades.sdb.internal.SDbPlugin;
import org.eclipse.hyades.sdb.internal.util.SdUIConstants;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.hyades.log.ui.internal.views.*;

/**
 * @author sleeloy
 *
 * This action class will analyze an apache error log using 
 * a specific symptom database.  The corresponding viewers are 
 * also refeshed to reflect the analyzed error log file.
 */
public class AnalyzeLogAction implements IRunnableWithProgress {

	private String symptomDBPath;
	private String projectName;
	private String sdbFileName;
	
	private ExtensionPointHandler eph = ExtensionPointHandler.getExtensionPointHandler();
	protected EObject mofObject;
	private LogPaneTreeViewer logPaneTreeViewer;	
	/**
	 * This method is were all the work is done.  The error log file is analyzed
	 * using a specified symptom database.  The Log Tree Viewer is also refreshed
	 * to reflect the analyzed error log file.
	 * 
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 * @param monitor - shows the progress of this action.
	 */
	public void run(IProgressMonitor monitor)
		throws InvocationTargetException, InterruptedException {
			//Need to set the symptom database path
			IPreferenceStore store = SDbPlugin.getDefault().getPreferenceStore();
			
			String value = getNewSDBPathPreference(store.getString(SdUIConstants.SYMPTOM_DB_PATH_KEY), symptomDBPath);
			store.setValue(SdUIConstants.SYMPTOM_DB_PATH_KEY, value);
			store.setValue(SdUIConstants.PROJECT_NAME_KEY, projectName);
			store.setValue(SdUIConstants.SDB_FILE_NAME_KEY, sdbFileName);
			
			//Load symptom database
			IStructuredSelection  selection = getSelection();
			List aLogAnalyzerList = eph.getLogAnalyzers();
			LogAnalyzerImpl aLogAnalyzerImpl = null;
			
			if(aLogAnalyzerList != null && aLogAnalyzerList.size() >0)
			{
				for (Iterator iter = aLogAnalyzerList.iterator();
				iter.hasNext();
				) {
					ConfigurationElement config = (ConfigurationElement) iter.next();
					if(config.getAnalyzer() instanceof LogAnalyzerImpl){
						aLogAnalyzerImpl = (LogAnalyzerImpl)config.getAnalyzer();
						break;	
					}
				}
								
			}
			if(aLogAnalyzerImpl == null)
			    return;
			
			if (sdbFileName.length() > 0) aLogAnalyzerImpl.importDB(monitor); 
			aLogAnalyzerImpl.loadDatabase();
			if(aLogAnalyzerImpl.errorMsg()==null){	
				aLogAnalyzerImpl.analyze(selection, null);
			}
			logPaneTreeViewer.refresh();

			//Need to send an event so that the Analysis Result area will be updated.
			Event event = new Event();
			event.item = ((Tree) logPaneTreeViewer.getControl()).getItems()[0];
			logPaneTreeViewer.getControl().notifyListeners(SWT.Selection, event);			

	}
	/**
	 * 
	 * @return
	 */
	private String getNewSDBPathPreference(String previousValue, String symptomDBPath)
	{
		//	case 1
		// nothing is stores in the preference
		// previous.length() == 0 if nothing is stored in the preference
		if (previousValue.length() == 0) 
		{
			return symptomDBPath + ",1"; 
		}
		 else
		 {
			 int index = previousValue.indexOf(symptomDBPath);
		
		
			 if (index < 0)
			 {
				 // case 2
				 // symptomdbpath does not exist in preference (ie.db has not been loaded)
				   return symptomDBPath + ",1" + ";" + previousValue;
			   }	
			   else
			   {
	
				   if ((previousValue.substring(symptomDBPath.length() + index + 1,symptomDBPath.length() + index + 2 )).equals("0"))
				   {
					   //case 3
					   //loaded but is followed by ,0 - meaning not used for log analysis
					   //change 0 to 1
					   String temp1 = previousValue.substring(0, index + symptomDBPath.length() + 1);
					   String temp2 = previousValue.substring(index + symptomDBPath.length() + 2, previousValue.length());
					   return temp1 + "1" + temp2;
				   }
	
				   else if ((previousValue.substring(symptomDBPath.length() + index + 1, symptomDBPath.length() + index + 2)).equals("1"))
				   {
					   // case 4
					   // loaded and is follow by a ,1
					   // do nothing
					   return previousValue;
				   }
		
				 }
		 }
		 return "";
	}
	
	/**
	 * This class retrieves the entire content selection from the Log Viewer.  All the contents
	 * in the log viewer will be analyzed.
	 * 
	 * @return IStructureSelection that represents the records shown in the Log Viewer.
	 */
	public IStructuredSelection getSelection(){
		//return the entire content selection
		try {
					IWorkbenchPage persp = UIPlugin.getActivePage();
					LogViewer logviewer = (LogViewer)persp.showView("org.eclipse.hyades.log.ui.internal.views.LogViewer");
					LogPage logPage = (LogPage)logviewer.getPage(mofObject);
					if(logPage==null){
						logviewer.addViewPage(mofObject);
						logPage = (LogPage)logviewer.getPage(mofObject);
					}
					
					logPaneTreeViewer = logPage.getView().getViewer();
					LogContentProvider logContentProvider = (LogContentProvider)logPaneTreeViewer.getContentProvider();
					return new StructuredSelection(logContentProvider.getChildren(mofObject));
		} catch (PartInitException e) {
			e.printStackTrace();
		}
		return null;
	}


	/**
	 * Returns the symptom database location that is used to analyze the error log file.
	 * @return String that represents the symptom database location that is used to analyze the error log file.
	 */
	public String getSymptomDBPath() {
		return symptomDBPath;
	}

	/**
	 * Sets the symptom database location that is used to analyze the error log file.
	 * @param string - that represents the symptom database location that is used to analyze the error log file.
	 */
	public void setSymptomDBPath(String string) {
		symptomDBPath = string;
	}
	
	/**
	 * Sets the project Name of where to import the db into
	 * @param pName
	 */
	public void setProjectName(String pName)
	{
		projectName = pName;
	}
		
	/**
	 * specifies what the sdb file should be called in the workspace
	 * @param string
	 */
	public void setSDBFileName(String string)
	{
		sdbFileName = string;
	}
		
	

	/**
	 * Returns the Mof object that represents the error log file.  This object will be analyzed using the 
	 * specified symptom database.
	 * @return EObject represents the error log file that will be analyzed.
	 */
	public EObject getMofObject() {
		return mofObject;
	}

	/**
	 * Sets the Mof object that represents the error log file.  This object will be analyzed using the 
	 * specified symptom database.
	 * @param object - represents the error log file that will be analyzed.
	 */
	public void setMofObject(EObject object) {
		mofObject = object;
	}

}
